#ifndef FILEDELEGATE_H
#define FILEDELEGATE_H

#include <QItemDelegate>

class FileDelegate : public QAbstractItemDelegate
{
    Q_OBJECT

public:
    FileDelegate(QObject *parent = 0, int multiselection = 0, QString col1 = "", QString col2 = "");
    int multi;
    QString color1, color2;
    void paint(QPainter *painter, const QStyleOptionViewItem &option,
               const QModelIndex &index) const;
    QSize sizeHint(const QStyleOptionViewItem &option,
                   const QModelIndex &index ) const;
};

#endif
